@@ -5,18 +5,19 @@ use std::option::Option::Some;
 
 extern crate itertools;
 
-pub fn parse_str(contents: &str, debug: bool) -> Option<Solution> {
-    let input;
+const UTF8_BOM: &[u8; 3] = b"\xEF\xBB\xBF";
 
-    let cb = contents.as_bytes();
-    if contents.len() < 3 {
+pub fn parse_str(contents: &str, debug: bool) -> Option<Solution> {
+    if contents.len() < UTF8_BOM.len() {
         return None;
     }
-    if cb[0] == b'\xEF' && cb[1] == b'\xBB' && cb[2] == b'\xBF' {
-        input = &contents[3..];
+    let cb = contents.as_bytes();
+    // Skip UTF-8 signature if necessary
+    let input = if &cb[0..UTF8_BOM.len()] == UTF8_BOM {
+        &contents[UTF8_BOM.len()..]
     } else {
-        input = contents;
-    }
+        contents
+    };
     let lexer = crate::lex::Lexer::new(input);
     match crate::solp::SolutionParser::new().parse(input, lexer) {
         Ok(ast) => {
@@ -52,10 +53,11 @@ macro_rules! section_content {
 fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'input> {
     let (head, lines) = solution;
 
-    let mut version = "";
-    if let Expr::FirstLine(ver) = head {
-        version = ver.digit_or_dot();
-    }
+    let version = if let Expr::FirstLine(ver) = head {
+        ver.digit_or_dot()
+    } else {
+        ""
+    };
 
     let mut sol = Solution {
         format: version,
@@ -69,18 +71,20 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     sol.projects.push(p);
                     sol.dependencies.add_node(p.id);
                 }
-                let last_id = &sol.projects[sol.projects.len() - 1].id;
-                let edges = sections
-                    .iter()
-                    .filter_map(|sect| section_content!(sect, "ProjectDependencies"))
-                    .flatten()
-                    .filter_map(|expr| match expr {
-                        Expr::SectionContent(left, _) => Some(left.string()),
-                        _ => None,
-                    })
-                    .map(|from| (from, *last_id));
 
-                sol.dependencies.extend(edges);
+                if let Some(last_project) = sol.projects.last() {
+                    let edges = sections
+                        .iter()
+                        .filter_map(|sect| section_content!(sect, "ProjectDependencies"))
+                        .flatten()
+                        .filter_map(|expr| match expr {
+                            Expr::SectionContent(left, _) => Some(left.string()),
+                            _ => None,
+                        })
+                        .map(|from| (from, last_project.id));
+
+                    sol.dependencies.extend(edges);
+                }
             }
             Expr::Version(name, val) => {
                 let version = Version::from(&name, &val);
@@ -203,6 +207,21 @@ mod tests {
 
     #[test]
     fn parse_str_no_line_break() {
+        // Arrange
+        let mut binary = Vec::new();
+        binary.extend_from_slice(UTF8_BOM);
+        binary.extend_from_slice(REAL_SOLUTION.as_bytes());
+        let sln = String::from_utf8(binary).unwrap();
+
+        // Act
+        let result = parse_str(&sln, false);
+
+        // Assert
+        assert_that!(&result).is_some();
+    }
+
+    #[test]
+    fn parse_str_start_from_utf_8_signature() {
         // Arrange
         let sln = REAL_SOLUTION.trim_end();
 
